Skip to main content
aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
Diffstat (limited to 'plugins/org.eclipse.emf.cdo/src/org/eclipse/emf/cdo/session/CDOCollectionLoadingPolicy.java')
-rw-r--r--plugins/org.eclipse.emf.cdo/src/org/eclipse/emf/cdo/session/CDOCollectionLoadingPolicy.java11
1 files changed, 6 insertions, 5 deletions
diff --git a/plugins/org.eclipse.emf.cdo/src/org/eclipse/emf/cdo/session/CDOCollectionLoadingPolicy.java b/plugins/org.eclipse.emf.cdo/src/org/eclipse/emf/cdo/session/CDOCollectionLoadingPolicy.java
index ba2ff3f645..bad1db2911 100644
--- a/plugins/org.eclipse.emf.cdo/src/org/eclipse/emf/cdo/session/CDOCollectionLoadingPolicy.java
+++ b/plugins/org.eclipse.emf.cdo/src/org/eclipse/emf/cdo/session/CDOCollectionLoadingPolicy.java
@@ -12,9 +12,10 @@
package org.eclipse.emf.cdo.session;
import org.eclipse.emf.cdo.common.id.CDOID;
-import org.eclipse.emf.cdo.common.model.CDOFeature;
import org.eclipse.emf.cdo.common.revision.CDORevision;
+import org.eclipse.emf.ecore.EStructuralFeature;
+
/**
* A strategy that specifies which list elememts must be present (loaded) in a {@link CDOID} list of a
* {@link CDORevision revision} when a certain list index is accessed. Implementations of this interface can control the
@@ -39,7 +40,7 @@ public interface CDOCollectionLoadingPolicy
return CDORevision.UNCHUNKED;
}
- public Object resolveProxy(CDORevisionManager revisionManager, CDORevision revision, CDOFeature feature,
+ public Object resolveProxy(CDORevisionManager revisionManager, CDORevision revision, EStructuralFeature feature,
int accessIndex, int serverIndex)
{
return revisionManager.loadChunkByRange(revision, feature, accessIndex, serverIndex, accessIndex, accessIndex);
@@ -54,9 +55,9 @@ public interface CDOCollectionLoadingPolicy
/**
* Defines a strategy to be used when the collection needs to resolve one element.
* {@link CDORevisionManager#loadChunkByRange(CDORevision, CDOFeature, int, int, int, int)} should be used to resolve
* them.
*/
- public Object resolveProxy(CDORevisionManager revisionManager, CDORevision revision, CDOFeature feature,
+ public Object resolveProxy(CDORevisionManager revisionManager, CDORevision revision, EStructuralFeature feature,
int accessIndex, int serverIndex);
}
@@ -54,9 +55,9 @@ public interface CDOCollectionLoadingPolicy
/**
* Defines a strategy to be used when the collection needs to resolve one element.
- * {@link CDORevisionManager#loadChunkByRange(CDORevision, CDOFeature, int, int, int, int)} should be used to resolve
- * them.
+ * {@link CDORevisionManager#loadChunkByRange(CDORevision, EStructuralFeature, int, int, int, int)} should be used to
+ * resolve them.
*/

Back to the top